.. ..  index.rst -*- mode: ReST -*-

.. _index:

==========================
Deja Vu: The Documentation
==========================

------------
Introduction
------------

JGDV is my kitchen sink library.
Things I keep writing that don't warrant a separate library get shoved in here.
Of interest:

#. :ref:`LogConfig<jgdv.logging.config>`
#. :ref:`Strang<jgdv.structs.strang>`
#. :ref:`ChainGuard<jgdv.structs.chainguard>`
#. :ref:`Locator<jgdv.structs.locator>`
#. :ref:`DKey<jgdv.structs.dkey>`

.. _repo:

---------------
Repo And Issues
---------------

The repo can be found `here <https://github.com/jgrey4296/jgdv>`_.

If you find a bug, bug me, unsurprisingly, on the `issue tracker <https://github.com/jgrey4296/jgdv/issues>`_.


.. .. Main Sidebar TocTree
.. toctree::
   :maxdepth: 3
   :glob:
   :hidden:
      
   _abstract/index
   
   [a-z]*/index

   _docs/*
   genindex
   modindex
   API Reference <_docs/autoapi/jgdv/index>
   

.. .. Links
